@@ -4,8 +4,7 @@ import (
 	"strconv"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 )
 
 func TestHexBytes(t *testing.T) {
@@ -33,11 +32,11 @@ func TestHexBytes(t *testing.T) {
 			} {
 				t.Run(format.Name(), func(t *testing.T) {
 					actual, err := format.Marshal(tc.b)
-					require.NoError(t, err)
+					assert.NoError(t, err)
 					assert.Equal(t, []byte(tc.expectedStr), actual)
-					var actualB HexBytes
-					require.NoError(t, format.Unmarshal(actual, &actualB))
-					assert.Equal(t, tc.b, actualB)
+					var actualHexBytes HexBytes
+					assert.NoError(t, format.Unmarshal(actual, &actualHexBytes))
+					assert.Equal(t, tc.b, actualHexBytes)
 				})
 			}
 		})
