@@ -6,12 +6,14 @@ import (
 
 func (c *Config) newEditConfigCmd() *cobra.Command {
 	editConfigCmd := &cobra.Command{
-		Use:     "edit-config",
-		Short:   "Edit the configuration file",
-		Long:    mustLongHelp("edit-config"),
-		Example: example("edit-config"),
-		Args:    cobra.NoArgs,
-		RunE:    c.runEditConfigCmd,
+		GroupID:           groupIDAdvanced,
+		Use:               "edit-config",
+		Short:             "Edit the configuration file",
+		Long:              mustLongHelp("edit-config"),
+		Example:           example("edit-config"),
+		Args:              cobra.NoArgs,
+		ValidArgsFunction: cobra.NoFileCompletions,
+		RunE:              c.runEditConfigCmd,
 		Annotations: newAnnotations(
 			doesNotRequireValidConfig,
 			modifiesConfigFile,
