@@ -10,8 +10,8 @@ import (
 	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v5"
 
-	"github.com/twpayne/chezmoi/internal/chezmoiassert"
-	"github.com/twpayne/chezmoi/internal/chezmoitest"
+	"chezmoi.io/chezmoi/internal/chezmoiassert"
+	"chezmoi.io/chezmoi/internal/chezmoitest"
 )
 
 func TestCommentTemplateFunc(t *testing.T) {
